summaryrefslogtreecommitdiffstats
path: root/installer
diff options
context:
space:
mode:
Diffstat (limited to 'installer')
-rw-r--r--installer/OpenSLX/OSSetup/Distro/Base.pm7
1 files changed, 6 insertions, 1 deletions
diff --git a/installer/OpenSLX/OSSetup/Distro/Base.pm b/installer/OpenSLX/OSSetup/Distro/Base.pm
index 23f1e038..b05e5cfe 100644
--- a/installer/OpenSLX/OSSetup/Distro/Base.pm
+++ b/installer/OpenSLX/OSSetup/Distro/Base.pm
@@ -126,7 +126,8 @@ sub startSession
"slxos-setup::distro::chroot", sub { $self->finishSession(); }
);
# make sure there's a /dev/zero and /dev/null
if (!-e "$osDir/dev" && !mkdir("$osDir/dev")) {
die _tr("unable to create folder '%s' (%s)\n", "$osDir/dev", $!);
}
@@ -136,6 +137,10 @@ sub startSession
if (!-e "$osDir/dev/null" && slxsystem("mknod $osDir/dev/null c 1 3")) {
die _tr("unable to create node '%s' (%s)\n", "$osDir/dev/null", $!);
}
+ if (!-e "$osDir/dev/urandom" && slxsystem("mknod $osDir/dev/urandom c 1 9")) {
+ die _tr("unable to create node '%s' (%s)\n", "$osDir/dev/urandom", $!);
+ }
+
# fake proc, depending on what is needed ...
if (!-e "$osDir/proc" && !mkdir("$osDir/proc")) {
@@ -126,7 +126,8 @@ sub startSession
"slxos-setup::distro::chroot", sub { $self->finishSession(); }
);
- # make sure there's a /dev/zero and /dev/null
+ # make sure there's a /dev/zero, /dev/null and /dev/urandom
+ # /dev/urandom for passwd chroot
if (!-e "$osDir/dev" && !mkdir("$osDir/dev")) {
die _tr("unable to create folder '%s' (%s)\n", "$osDir/dev", $!);